" Maintainer:   Natsagdorj Shagdar <natsag2000@yahoo.com>
" Last Changed: 2007 Jun 26

" All characters are given literally, conversion to another encoding (e.g.,
" UTF-8) should work.
scriptencoding utf-8

let b:keymap_name = "mn"

loadkeymap
C	Ё	CYRILLIC CAPITAL LETTER IO
c	ё	CYRILLIC SMALL LETTER IO
G	А	CYRILLIC CAPITAL LETTER A
D	Б	CYRILLIC CAPITAL LETTER BE
>	В	CYRILLIC CAPITAL LETTER VE
U	Г	CYRILLIC CAPITAL LETTER GHE
:	Д	CYRILLIC CAPITAL LETTER DE
_	Е	CYRILLIC CAPITAL LETTER IE
R	Ж	CYRILLIC CAPITAL LETTER ZHE
P	З	CYRILLIC CAPITAL LETTER ZE
N	И	CYRILLIC CAPITAL LETTER I
A	Й	CYRILLIC CAPITAL LETTER SHORT I
{	К	CYRILLIC CAPITAL LETTER KA
L	Л	CYRILLIC CAPITAL LETTER EL
B	М	CYRILLIC CAPITAL LETTER EM
Y	Н	CYRILLIC CAPITAL LETTER EN
K	О	CYRILLIC CAPITAL LETTER O
\"	П	CYRILLIC CAPITAL LETTER PE
J	Р	CYRILLIC CAPITAL LETTER ER
V	С	CYRILLIC CAPITAL LETTER ES
M	Т	CYRILLIC CAPITAL LETTER TE
E	У	CYRILLIC CAPITAL LETTER U
Q	Ф	CYRILLIC CAPITAL LETTER EF
H	Х	CYRILLIC CAPITAL LETTER HA
W	Ц	CYRILLIC CAPITAL LETTER TSE
X	Ч	CYRILLIC CAPITAL LETTER CHE
I	Ш	CYRILLIC CAPITAL LETTER SHA
+	Щ	CYRILLIC CAPITAL LETTER SHCHA
}	Ъ	CYRILLIC CAPITAL LETTER HARD SIGN
S	Ы	CYRILLIC CAPITAL LETTER YERU
<	Ь	CYRILLIC CAPITAL LETTER SOFT SIGN
T	Э	CYRILLIC CAPITAL LETTER E
?	Ю	CYRILLIC CAPITAL LETTER YU
Z	Я	CYRILLIC CAPITAL LETTER YA
g	а	CYRILLIC SMALL LETTER A
d	б	CYRILLIC SMALL LETTER BE
.	в	CYRILLIC SMALL LETTER VE
u	г	CYRILLIC SMALL LETTER GHE
;	д	CYRILLIC SMALL LETTER DE
-	е	CYRILLIC SMALL LETTER IE
r	ж	CYRILLIC SMALL LETTER ZHE
p	з	CYRILLIC SMALL LETTER ZE
n	и	CYRILLIC SMALL LETTER I
a	й	CYRILLIC SMALL LETTER SHORT I
[	к	CYRILLIC SMALL LETTER KA
l	л	CYRILLIC SMALL LETTER EL
b	м	CYRILLIC SMALL LETTER EM
y	н	CYRILLIC SMALL LETTER EN
k	о	CYRILLIC SMALL LETTER O
'	п	CYRILLIC SMALL LETTER PE
j	р	CYRILLIC SMALL LETTER ER
v	с	CYRILLIC SMALL LETTER ES
m	т	CYRILLIC SMALL LETTER TE
e	у	CYRILLIC SMALL LETTER U
q	ф	CYRILLIC SMALL LETTER EF
h	х	CYRILLIC SMALL LETTER HA
w	ц	CYRILLIC SMALL LETTER TSE
x	ч	CYRILLIC SMALL LETTER CHE
i	ш	CYRILLIC SMALL LETTER SHA
=	щ	CYRILLIC SMALL LETTER SHCHA
]	ъ	CYRILLIC SMALL LETTER HARD SIGN
s	ы	CYRILLIC SMALL LETTER YERU
,	ь	CYRILLIC SMALL LETTER SOFT SIGN
t	э	CYRILLIC SMALL LETTER E
/	ю	CYRILLIC SMALL LETTER YU
z	я	CYRILLIC SMALL LETTER YA
f	ө	CYRILLIC SMALL LETTER Oе
F	Ө	CYRILLIC SMALL LETTER Oе
o	ү	CYRILLIC SMALL LETTER Ге
O	Ү	CYRILLIC SMALL LETTER Oе
`	=
1	№	NUMERO SIGN
2	-
3	"
4	T
5	:
7	?
6	.
8	,
9	(
0	)
!	1
@	2
#	3
$	4
%	5
^	6
&	7
*	8
(	9
)	0
